ete2.coretype.seqgroup

Package ete2 :: Package coretype :: Module seqgroup |
[hide private]
[frames] | no frames]

# Module seqgroup

source code

Classes | [hide private]
| SeqGroup SeqGroup class can be used to store a set of sequences (aligned or not).

Variables | [hide private]
| __VERSION__ = ``'``ete2-2.0rev90``'`` The 'seqgroup' module provides methods and classes to operate with Multiple Sequence Files, including Multiple Sequence Alignments.
| __package__ = ``'``ete2.coretype``'``

Variables Details | [hide private]

  ### __VERSION__ The 'seqgroup' module provides methods and classes to operate with Multiple Sequence Files, including Multiple Sequence Alignments. Currently, Fasta, Phylip sequencial and Phylip interleaved formats are supported. Value:
      'ete2-2.0rev90'